@@ -30,9 +30,9 @@ def download_boilerplate_git_folder(output_filename):
                 f.write(chunk)
 
 
-def make_venv():
-    os.system(f"python3 -m venv {VENV_NAME}")
-    os.system(f"source {VENV_NAME}/bin/activate && pip install -r requirements.txt")
+def make_venv(venv_name: str = VENV_NAME):
+    os.system(f"python3 -m venv {venv_name}")
+    os.system(f"source {venv_name}/bin/activate && pip install -r requirements.txt")
 
 
 @app.command()
@@ -63,7 +63,7 @@ def create(project_name: str = typer.Argument("magic-server"), replace: bool = F
 
 
 @app.command()
-def dev(create_venv: bool = True):
+def dev(venv_name: str = typer.Argument(VENV_NAME), create_venv: bool = True):
     main_filename = "main.py"
     if not Path(main_filename).exists():
         typer.echo(
@@ -74,17 +74,22 @@ def dev(create_venv: bool = True):
     command = f"export LOCAL=1 && python {main_filename}"
 
     prefix = getattr(sys, "prefix", "")
-    if VENV_NAME not in prefix and create_venv:
+    if venv_name not in prefix and create_venv:
         typer.echo("no venv detected, will make own now")
-        make_venv()
-        command = f"source {VENV_NAME}/bin/activate && {command}"
+        venv_path = Path(venv_name)
+        if not venv_path.exists():
+            print("VENV PATH", venv_path)
+            print("cwd", Path.cwd())
+            print("dir", os.listdir())
+            make_venv(venv_name)
+        command = f"source {venv_name}/bin/activate && {command}"
 
     os.system(command)
 
 
 @app.command()
 def version():
-    typer.echo("5")
+    typer.echo("6")
 
 
 if __name__ == "__main__":
